@@ -1,5 +1,5 @@
 from abc import ABC, abstractmethod
-from src.simcalibration.utils.Data import Data
+from simcalibration.utils.Data import Data
 
 
 class DGModel(ABC):
@@ -10,6 +10,10 @@ class DGModel(ABC):
         self.model = None
         self.learned = learned
         self.num_vars = num_vars
+        # metadata used downstream
+        self.var_names = None  # list[str], canonical variable order (incl. outcome)
+        self.learned_dag = None  # np.ndarray adjacency learned from SL
+
         if SLClass is not None:
             self.instantiate()
 
