@@ -1,5 +1,5 @@
 from abc import ABC, abstractmethod
-from src.simcalibration.utils.Data import Data
+from simcalibration.utils.Data import Data
 import pandas as pd
 
 
