@@ -231,8 +231,8 @@ class Evaluator:
 
         if SLClass == "hc":
             robjects.r('''
-                        if(!require(bnlearn)) install.packages('bnlearn')
-                        if(!require(plyr)) install.packages('plyr')
+                        library(bnlearn)
+                        library(plyr)
                         bn_learn <- function(learning_data_real, n_train, n_test, verbose=FALSE) {     
                         learning_data_real <- data.frame(lapply(learning_data_real,as.factor), stringsAsFactors=TRUE)         
                         check_and_modify_levels <- function(column){
@@ -477,7 +477,7 @@ class Evaluator:
         bn_hc = robjects.r['bn_learn']
         bn_train_output = bn_hc(learning_data_real, n_train, n_test)
 
-        # --- Extract train/test arrays (as before) ---
+        # --- Extract train/test arrays ---
         try:
             train_array = np.array(bn_train_output.rx2('train'), dtype=np.int64)
             test_array = np.array(bn_train_output.rx2('test'), dtype=np.int64)
@@ -486,7 +486,7 @@ class Evaluator:
             train_array = np.array(bn_train_output[0], dtype=np.int64)
             test_array = np.array(bn_train_output[1], dtype=np.int64)
 
-        # --- Build Data objects (same as before) ---
+        # --- Build Data objects ---
         X = pd.DataFrame(train_array[:, :-1])
         y = pd.Series(train_array[:, -1], name="Y")
         train_data = Data(name="train", X=X, y=y)
@@ -514,7 +514,7 @@ class Evaluator:
             dg_model.learned_dag = None
             dg_model.var_names = None
 
-        # --- CV and ML evaluation (unchanged) ---
+        # --- CV and ML evaluation  ---
         kf = KFold(n_splits=kfolds, shuffle=True, random_state=42)
         cv_metrics = {}
 
